@@ -9,8 +9,7 @@ namespace Tomboy
 	{
 		static readonly string[] DefaultEnabledPlugins = {
 			"BacklinksPlugin", "EvolutionPlugin", "ExportToHTMLPlugin",
-			"FixedWidthPlugin", "NoteOfTheDayPlugin", "PrintPlugin",
-			"StickyNoteImporter"
+			"FixedWidthPlugin", "PrintPlugin", "StickyNoteImporter"
 		};
 
 		public const string ENABLE_SPELLCHECKING = "/apps/tomboy/enable_spellchecking";
@@ -18,6 +17,7 @@ namespace Tomboy
 		public const string ENABLE_CUSTOM_FONT = "/apps/tomboy/enable_custom_font";
 		public const string ENABLE_KEYBINDINGS = "/apps/tomboy/enable_keybindings";
 
+		public const string START_NOTE_URI = "/apps/tomboy/start_note";
 		public const string CUSTOM_FONT_FACE = "/apps/tomboy/custom_font_face";
 		public const string MENU_NOTE_COUNT = "/apps/tomboy/menu_note_count";
 		public const string MENU_PINNED_NOTES = "/apps/tomboy/menu_pinned_notes";
@@ -56,12 +56,17 @@ namespace Tomboy
 		{
 			switch (key) {
 			case ENABLE_SPELLCHECKING:
-			case ENABLE_CUSTOM_FONT:
 			case ENABLE_KEYBINDINGS:
 				return true;
 
+			case ENABLE_CUSTOM_FONT:
+				return false;
+
 			case ENABLE_WIKIWORDS:
 				return false;
+			
+			case START_NOTE_URI:
+				return String.Empty;
 
 			case CUSTOM_FONT_FACE:
 				return "Serif 11";
